from setuptools import setup, find_packages

setup(
    name='padraowebscraping',
    version='0.1.0',
    author='Eduardo Levi Cordeiro',
    author_email='eduardocordeiro1906@gmail.com',
    description='Uma biblioteca para criar a estrutura padrão de pastas para projetos',
    packages=find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)